# Tikos Reasoning Platform

Tikos Reasoning Platform harnesses the power of empirically established 2nd-generation AI and statistical toolsets to offer its users advanced 3rd-generation AI capabilities.

Copyright 2024 (C) Tikos Technologies Limited

## How to access the platform

To get Alpha API keys, please register your request via https://tikos.tech/

## Licence

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

## Release Notes

1. v 0.0.7, added 

   i. GetGraphStructure: Automatically extract graph Vertices and Edges that can be further refined by the user

   ii. GenerateGraph: Provide Tikos Reasoning Platform the refined graph Vertices and Edges to build the standard knowledge graph

   iii. GetGraph: Get the whole graph for an extraction request

   iv. GetGraphRelationships: Get relationships between two Vertexes

2. v 0.0.8, added

   i. GetGraphRetrieval: Retrieve query response along with the Graph relationships for the requested retrieve query

3. v 0.0.9, added

   i. GetGraphRetrievalWithDS: Retrieve query response along with the Graph relationships for the requested retrieve query with Graph Node data sets as JSON

4. v 0.1.0, added

   i. Licence conditions

5. v 0.1.1

   i. Added, ProcessExtractFile: Be able to extract data from a specific file and support JSON based extraction using jq based schemas

   ii. Modified, ProcessExtract: Support JSON based extraction using jq based schemas

6. v0.1.1

   i. Added, BuildSC: Generate the SequentialCollection knowledge structure for the associated graph Vertices from structured data sets

   ii. Added, GetSimilarCase: Providing a Problem Space (PS) case, the Sequential collection will contact a basic binary (BIN, default) search or advanced binary (BINADV) search and return the most similar existing case. This does not perform any case adaptation

7. v0.1.4

   i. Added, GetGraphStructurePerDoc: Accept a file names and generate NER JSON of the (submitted) file

   ii. Added, GenerateGraphPerDoc: Accept a NER JSON object and create a graph of the (submitted) file

   iii. Added, GenerateAutoGraph: Accept a list of file names, that will be used to generate the NER generation automatically and create a full graph

8. v0.1.6

   i. Amended, GetGraphRetrieval: to accept optional file reference and base model reference

   ii. Amended, GetGraphRetrievalWithDS: to accept optional file reference and base model reference

9. v0.1.7

   i. Added, GetCustomerGraphRetrievalWithDS: Retrieve customer specific query with the Graph relationships for the requested retrieve query with Graph Node data sets as JSON

10. v0.1.8

   i. Amended, GenerateGraph, GenerateGraphPerDoc & GenerateAutoGraph: to accept graph generation Payload Configuration with the JSON format: {"overrideNER":"<True/False>", "filter":"<GRAPH CASE_TYPE ATTRIBUTE GENERATION CONFIG TEXT>"}